@@ -335,7 +335,7 @@ mod_authn_crypt_cmp (const char *reqpw, const char *userpw, unsigned long userpw
     char *crypted = crypt(reqpw, userpw);
     size_t crypwlen = (NULL != crypted) ? strlen(crypted) : 0;
     int rc = (crypwlen == userpwlen) ? memcmp(crypted, userpw, crypwlen) : -1;
-    if (crypwlen) ck_memzero(crypted, crypwlen);
+    if (crypwlen >= 13) ck_memzero(crypted, crypwlen);
     return rc;
 
  #else
@@ -363,7 +363,7 @@ mod_authn_crypt_cmp (const char *reqpw, const char *userpw, unsigned long userpw
     size_t crypwlen = (NULL != crypted) ? strlen(crypted) : 0;
     int rc = (crypwlen == userpwlen) ? memcmp(crypted, userpw, crypwlen) : -1;
 
-    ck_memzero(crypted, crypwlen);
+    if (crypwlen >= 13) ck_memzero(crypted, crypwlen);
   #if defined(HAVE_CRYPT_R)
    #if 1 /* (must free() if allocated above) */
     free(crypt_tmp_data);
